iScroll demo: snap

iScroll

- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell
- Cell